import {Component, EventEmitter, Input, Output} from '@angular/core';
import {GameModel} from "../../game-model/GameModel";
import {ScriptAccount} from "../../game-model/scriptAccounts/ScriptAccount";
import {ElectronService} from "../../core/services";

@Component({
  selector: 'app-script-account-overview',
  templateUrl: './script-account-overview.component.html',
  styleUrl: './script-account-overview.component.css'
})
export class ScriptAccountOverviewComponent {
  @Input("gameModel") gameModel: GameModel | undefined
  @Output("onOpenScriptAccount") openScriptAccountEmitter: EventEmitter<ScriptAccount> = new EventEmitter<ScriptAccount>();

  constructor(private electronService: ElectronService) {
  }

  onOpenScriptAccount(scriptAccount: ScriptAccount) {
    console.log("onOpenScriptAccount (overview)")
    this.openScriptAccountEmitter.emit(scriptAccount);
  }

  onCreateNewScriptAccount() {
    const scriptAccount = new ScriptAccount("New ScriptAccount", "");
    this.gameModel?.addScriptAccount(scriptAccount);
    return scriptAccount;
  }

  onContextMenu(event: MouseEvent) {
    if(this.electronService.isElectron) {
      console.log("[DEBUG] [ScriptAccountOverviewComponent] App is executed in electron")

    } else {
      console.log("[DEBUG] [ScriptAccountOverviewComponent] App is not executed in electron")
    }
  }
}
